"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveSecrets = exports.loadSecrets = void 0;
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const dotenv_1 = tslib_1.__importDefault(require("dotenv"));
const core_1 = require("@oclif/core");
const loadSecrets = async () => {
    const config = await core_1.Config.load();
    const secretsFilePath = path_1.default.resolve(config.configDir, 'secrets.json');
    const { parsed: dotEnv } = dotenv_1.default.config();
    if (!fs_1.default.existsSync(secretsFilePath)) {
        return dotenv_1.default;
    }
    const secretsFileContent = fs_1.default.readFileSync(secretsFilePath, 'utf8');
    const secrets = JSON.parse(secretsFileContent);
    Object.entries(secrets).forEach(([key, value]) => {
        var _a;
        process.env[key] = (_a = (dotEnv && dotEnv[key])) !== null && _a !== void 0 ? _a : String(value);
    });
    return secrets;
};
exports.loadSecrets = loadSecrets;
const saveSecrets = async (secrets) => {
    const config = await core_1.Config.load();
    const secretsFilePath = path_1.default.resolve(config.configDir, 'secrets.json');
    if (!fs_1.default.existsSync(config.configDir)) {
        fs_1.default.mkdirSync(config.configDir, { recursive: true });
    }
    fs_1.default.writeFileSync(secretsFilePath, JSON.stringify(secrets, null, 2));
};
exports.saveSecrets = saveSecrets;
