"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const puppeteer_1 = tslib_1.__importDefault(require("puppeteer"));
const log_1 = require("../utils/log");
class InstagramUploadService {
    constructor(content) {
        this.urls = {
            login: 'https://instagram.com/accounts/login',
            igtvUpload: 'https://www.instagram.com/tv/upload',
        };
        this.defaultHashtags = [
            'CodeStackNews',
            'noticias',
            'technews',
            'noticiasrapidas',
            'tecnologia',
            'ia',
            'programacao',
            'newsletter',
            'newsletterfilipedeschamps',
            'remotion',
            'dev',
            'desenvolvimento',
        ];
        this.content = content;
        if (!process.env.CHROME_BIN) {
            log_1.error('Chrome bin path is not defined', 'InstagramUploadService'); // NEEDED FOR INSTAGRAM, BECAUSE WITH CHROMIUM DOESN'T WORK
            process.exit(1);
        }
        if (!process.env.INSTAGRAM_EMAIL) {
            log_1.error('Instagram e-mail is not defined', 'InstagramUploadService');
            process.exit(1);
        }
        if (!process.env.INSTAGRAM_PASSWORD) {
            log_1.error('Instagram password is not defined', 'InstagramUploadService');
            process.exit(1);
        }
        this.chromeExecutablePath = process.env.CHROME_BIN;
        this.email = process.env.INSTAGRAM_EMAIL;
        this.password = process.env.INSTAGRAM_PASSWORD;
    }
    async execute(videoPath, thumbnailPath) {
        const details = this.getDetails();
        const browser = await puppeteer_1.default.launch({
            executablePath: this.chromeExecutablePath,
            headless: false,
            defaultViewport: null,
            args: ['--no-sandbox', '--disable-setuid-sandbox'],
        });
        const page = await browser.newPage();
        await page.goto(this.urls.login);
        await page.waitForSelector("input[name='username']");
        const usernameInput = await page.$("input[name='username']");
        const passwordInput = await page.$("input[name='password']");
        const loginButton = await page.$('button');
        if (!usernameInput || !passwordInput || !loginButton) {
            log_1.error('Failed to find username or password inputs', 'InstagramUploadService');
            process.exit(1);
        }
        log_1.log('Logging at instagram', 'InstagramUploadService');
        await usernameInput.click();
        await page.keyboard.type(this.email);
        await passwordInput.click();
        await page.keyboard.type(this.password);
        await loginButton.click();
        await page.waitForNavigation();
        await page.goto(this.urls.igtvUpload);
        log_1.log('Uploading video', 'InstagramUploadService');
        const [videoInput, thumbnailInput] = await page.$$('input[type="file"]');
        if (!videoInput || !thumbnailInput) {
            log_1.error('Failed to find media input ', 'InstagramUploadService');
            return;
        }
        videoInput.uploadFile(videoPath);
        await page.waitForFunction(() => Array.from(document.querySelectorAll('div')).find(div => div.innerText.includes('100%')), { timeout: 120000 });
        log_1.log('Upload completed', 'InstagramUploadService');
        thumbnailInput.uploadFile(thumbnailPath);
        try {
            log_1.log(`Setting details to: \n${details}`, 'InstagramUploadService');
            await page.type('textarea', details);
        }
        catch (e) {
            log_1.log('Failed to set description', 'InstagramUploadService');
        }
        const submitButton = await page.$('button');
        if (!submitButton) {
            log_1.error('Failed to find submit button', 'InstagramUploadService');
            return;
        }
        await submitButton.click();
        await page.waitForSelector('button img');
        await browser.close();
        log_1.log(`Video published on Instagram`, 'InstagramUploadService');
    }
    getDetails() {
        var _a;
        let details = `[CodeStack News] ${this.content.title} \n\n`;
        this.content.news.forEach(news => {
            const [title, _] = news.text.split(': ');
            details += `• ${title} \n`;
        });
        if (((_a = this.content.end) === null || _a === void 0 ? void 0 : _a.text) &&
            (this.content.end.shortLink || this.content.end.url)) {
            details += `\n\n${this.content.end.text} \n${this.content.end.shortLink || this.content.end.url} \n\n`;
        }
        this.defaultHashtags.forEach(hashtag => {
            details += `#${hashtag} `;
        });
        return details;
    }
}
exports.default = InstagramUploadService;
