"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLatestFileCreated = void 0;
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const log_1 = require("./log");
const defaultPaths_1 = require("../config/defaultPaths");
const getLatestFileCreated = async (fileExt, dirPath) => {
    var _a;
    if (!dirPath) {
        dirPath = await defaultPaths_1.getPath('tmp');
    }
    const files = fs_1.default.readdirSync(dirPath);
    const mostRecentlyCreatedFile = (_a = files
        .filter(file => path_1.default.extname(file) === `.${fileExt}`)
        .map(file => ({
        file,
        creationTime: Number(file.split('.')[0].split('-')[0]),
    }))
        .filter(file => !Number.isNaN(file.creationTime))
        .sort((a, b) => a.creationTime - b.creationTime)
        .pop()) === null || _a === void 0 ? void 0 : _a.file;
    if (!mostRecentlyCreatedFile) {
        log_1.error(`No ${fileExt} file in ${dirPath}`);
        process.exit(1);
    }
    return path_1.default.resolve(dirPath, mostRecentlyCreatedFile);
};
exports.getLatestFileCreated = getLatestFileCreated;
